==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property max Maximum.
 * @property min Minimum.
 */
public data class LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs(
    public val max: Output<Double>? = null,
    public val min: Output<Double>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs> {
    override fun toJava():
        com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs =
        com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs.builder()
            .max(max?.applyValue({ args0 -> args0 }))
            .min(min?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs].
 */
@PulumiTagMarker
public class LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgsBuilder internal
constructor() {
    private var max: Output<Double>? = null

    private var min: Output<Double>? = null

    /**
     * @param value Maximum.
     */
    @JvmName("fclkolesglwsdukn")
    public suspend fun max(`value`: Output<Double>) {
        this.max = value
    }

    /**
     * @param value Minimum.
     */
    @JvmName("bhjkbefxquvxxyot")
    public suspend fun min(`value`: Output<Double>) {
        this.min = value
    }

    /**
     * @param value Maximum.
     */
    @JvmName("yeeudiwbdndqqunf")
    public suspend fun max(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.max = mapped
    }

    /**
     * @param value Minimum.
     */
    @JvmName("cpannpjfutxolwmo")
    public suspend fun min(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.min = mapped
    }

    internal fun build(): LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs =
        LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs(
            max = max,
            min = min,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property max Maximum.
 * @property min Minimum.
 */
public data class LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs(
    public val max: Output<Double>? = null,
    public val min: Output<Double>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs =
        com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs.builder()
            .max(max?.applyValue({ args0 -> args0 }))
            .min(min?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs].
 */
@PulumiTagMarker
public class LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgsBuilder internal constructor() {
    private var max: Output<Double>? = null

    private var min: Output<Double>? = null

    /**
     * @param value Maximum.
     */
    @JvmName("peeymavnsrxcxttg")
    public suspend fun max(`value`: Output<Double>) {
        this.max = value
    }

    /**
     * @param value Minimum.
     */
    @JvmName("xlqagigmnmygjlsc")
    public suspend fun min(`value`: Output<Double>) {
        this.min = value
    }

    /**
     * @param value Maximum.
     */
    @JvmName("aehqsphxhkqnakha")
    public suspend fun max(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.max = mapped
    }

    /**
     * @param value Minimum.
     */
    @JvmName("juchcprjwsyjfkik")
    public suspend fun min(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.min = mapped
    }

    internal fun build(): LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs =
        LaunchTemplateInstanceRequirementsNetworkBandwidthGbpsArgs(
            max = max,
            min = min,
        )
}
